@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2010-2012 Aurimas Cernius
+ * Copyright (C) 2010-2013 Aurimas Cernius
  * Copyright (C) 2010 Debarshi Ray
  * Copyright (C) 2009 Hubert Figuiere
  *
@@ -229,14 +229,30 @@ namespace gnote {
     return note_path;
   }
 
+  bool Gnote::show_tray_icon_timeout()
+  {
+    // Setting to false and back to true is required to make it work on some tray implementations
+    m_tray_icon->set_visible(false);
+    m_tray_icon->set_visible(true);
+    return false;
+  }
+
   void Gnote::start_tray_icon()
   {
     // Create Search All Notes window as we need it present for application to run
     get_main_window();
 
-    // Create the tray icon and run the main loop
-    m_tray_icon = Glib::RefPtr<TrayIcon>(new TrayIcon(default_note_manager()));
-    m_tray = m_tray_icon->tray();
+    if(!m_tray_icon) {
+      // Create the tray icon and run the main loop
+      m_tray_icon = Glib::RefPtr<TrayIcon>(new TrayIcon(default_note_manager()));
+      m_tray = m_tray_icon->tray();
+    }
+
+    // Tome make status icon visible on some implementations, it should be made visible
+    // after some timeout.
+    Glib::RefPtr<Glib::TimeoutSource> timeout = Glib::TimeoutSource::create(100);
+    timeout->connect(sigc::mem_fun(*this, &Gnote::show_tray_icon_timeout));
+    timeout->attach();
   }
 
 
@@ -263,14 +279,12 @@ namespace gnote {
     bool use_status_icon = Preferences::obj()
       .get_schema_settings(Preferences::SCHEMA_GNOTE)->get_boolean(key);
     if(use_status_icon) {
-      if(!m_tray_icon) {
-        m_tray_icon = Glib::RefPtr<TrayIcon>(new TrayIcon(default_note_manager()));
-      }
-      m_tray_icon->set_visible(true);
+      start_tray_icon();
     }
     else {
-      if(m_tray_icon)
+      if(m_tray_icon) {
         m_tray_icon->set_visible(false);
+      }
       ActionManager::obj()["ShowSearchAllNotesAction"]->activate();
     }
   }
@@ -348,7 +362,7 @@ namespace gnote {
     about.set_program_name("Gnote");
     about.set_version(VERSION);
     about.set_logo(IconManager::obj().get_icon(IconManager::GNOTE, 48));
-    about.set_copyright(_("Copyright \xc2\xa9 2010-2012 Aurimas Cernius\n"
+    about.set_copyright(_("Copyright \xc2\xa9 2010-2013 Aurimas Cernius\n"
                           "Copyright \xc2\xa9 2009-2011 Debarshi Ray\n"
                           "Copyright \xc2\xa9 2009 Hubert Figuiere\n"
                           "Copyright \xc2\xa9 2004-2009 the Tomboy original authors."));
@@ -378,7 +392,7 @@ namespace gnote {
 
   NoteRecentChanges *Gnote::new_main_window()
   {
-    NoteRecentChanges *win = manage(new NoteRecentChanges(default_note_manager()));
+    NoteRecentChanges *win = new NoteRecentChanges(default_note_manager());
     win->signal_hide().connect(sigc::mem_fun(*this, &Gnote::on_main_window_closed));
     add_window(*win);
     return win;
