@@ -26,10 +26,12 @@
 #include <boost/bind.hpp>
 #include <glibmm/i18n.h>
 #include <gtkmm/image.h>
+#include <gtkmm/stock.h>
 
 #include "actionmanager.hpp"
 #include "debug.hpp"
 #include "gnote.hpp"
+#include "iconmanager.hpp"
 #include "note.hpp"
 #include "notemanager.hpp"
 #include "notewindow.hpp"
@@ -61,17 +63,7 @@ namespace gnote {
     m_search_notes_widget.signal_open_note_new_window
       .connect(sigc::mem_fun(*this, &NoteRecentChanges::on_open_note_new_window));
 
-    Gtk::Toolbar *toolbar = manage(new Gtk::Toolbar);
-    m_menu = manage(new Gtk::Menu);
-    m_menu->signal_show().connect(sigc::mem_fun(*this, &NoteRecentChanges::on_menu_show));
-    utils::ToolMenuButton *tool_button = manage(new utils::ToolMenuButton(
-      *manage(new Gtk::Image(utils::get_icon("note", 24))), _("_Show"), m_menu));
-    tool_button->set_use_underline(true);
-    tool_button->set_is_important(true);
-    tool_button->show_all();
-    toolbar->append(*tool_button);
-    toolbar->show();
-
+    Gtk::Toolbar *toolbar = make_toolbar();
     m_content_vbox.pack_start(*toolbar, false, false, 0);
     m_content_vbox.pack_start(m_embed_box, true, true, 0);
     m_embed_box.show();
@@ -88,11 +80,44 @@ namespace gnote {
 
   NoteRecentChanges::~NoteRecentChanges()
   {
-    while(m_embeded_widgets.size()) {
-      unembed_widget(**m_embeded_widgets.begin());
+    while(m_embedded_widgets.size()) {
+      unembed_widget(**m_embedded_widgets.begin());
     }
   }
 
+  Gtk::Toolbar *NoteRecentChanges::make_toolbar()
+  {
+    Gtk::Toolbar *toolbar = manage(new Gtk::Toolbar);
+    m_all_notes_button = manage(new Gtk::ToolButton(
+      *manage(new Gtk::Image(Gtk::Stock::FIND, Gtk::IconSize(24))), _("All Notes")));
+    m_all_notes_button->set_is_important();
+    m_all_notes_button->signal_clicked().connect(sigc::mem_fun(*this, &NoteRecentChanges::present_search));
+    m_all_notes_button->show_all();
+    toolbar->append(*m_all_notes_button);
+
+    Gtk::ToolButton *button = manage(new Gtk::ToolButton(
+      *manage(new Gtk::Image(IconManager::obj().get_icon(IconManager::NOTE_NEW, 24))),
+      _("New")));
+    button->set_is_important();
+    button->signal_clicked().connect(sigc::mem_fun(m_search_notes_widget, &SearchNotesWidget::new_note));
+    button->show_all();
+    toolbar->append(*button);
+
+    toolbar->show();
+    return toolbar;
+  }
+
+  void NoteRecentChanges::present_search()
+  {
+    utils::EmbeddableWidget *current = currently_embedded();
+    if(&m_search_notes_widget == dynamic_cast<SearchNotesWidget*>(current)) {
+      return;
+    }
+    if(current) {
+      background_embedded(*current);
+    }
+    foreground_embedded(m_search_notes_widget);
+  }
 
   void NoteRecentChanges::present_note(const Note::Ptr & note)
   {
@@ -113,17 +138,11 @@ namespace gnote {
   }
 
 
-  NoteRecentChanges::Ptr NoteRecentChanges::get_owning(Gtk::Widget & widget)
+  NoteRecentChanges *NoteRecentChanges::get_owning(Gtk::Widget & widget)
   {
-    Ptr owner;
     Gtk::Container *container = widget.get_parent();
     if(!container) {
-      try {
-        return dynamic_cast<NoteRecentChanges &>(widget).shared_from_this();
-      }
-      catch(std::bad_cast &) {
-        return owner;
-      }
+      return dynamic_cast<NoteRecentChanges*>(&widget);
     }
 
     Gtk::Container *cntr = container->get_parent();
@@ -132,12 +151,7 @@ namespace gnote {
       cntr = container->get_parent();
     }
 
-    NoteRecentChanges *recent_changes = dynamic_cast<NoteRecentChanges*>(container);
-    if(recent_changes) {
-      owner = recent_changes->shared_from_this();
-    }
-
-    return owner;
+    return dynamic_cast<NoteRecentChanges*>(container);
   }
 
 
@@ -148,7 +162,7 @@ namespace gnote {
 
   void NoteRecentChanges::on_open_note_new_window(const Note::Ptr & note)
   {
-    NoteRecentChanges::Ptr window = Gnote::obj().new_main_window();
+    NoteRecentChanges *window = Gnote::obj().new_main_window();
     window->present();
     window->present_note(note);
   }
@@ -168,9 +182,9 @@ namespace gnote {
     std::vector<Gtk::Widget*> current = m_embed_box.get_children();
     for(std::vector<Gtk::Widget*>::iterator iter = current.begin();
         iter != current.end(); ++iter) {
-      utils::EmbedableWidget *widget = dynamic_cast<utils::EmbedableWidget*>(*iter);
+      utils::EmbeddableWidget *widget = dynamic_cast<utils::EmbeddableWidget*>(*iter);
       if(widget) {
-        background_embeded(*widget);
+        background_embedded(*widget);
       }
     }
 
@@ -189,15 +203,15 @@ namespace gnote {
     switch (ev->keyval) {
     case GDK_KEY_Escape:
       // Allow Escape to close the window
-      if(&m_search_notes_widget == dynamic_cast<SearchNotesWidget*>(currently_embeded())) {
+      if(&m_search_notes_widget == dynamic_cast<SearchNotesWidget*>(currently_embedded())) {
         on_close_window();
       }
       else {
-        utils::EmbedableWidget *current_item = currently_embeded();
+        utils::EmbeddableWidget *current_item = currently_embedded();
         if(current_item) {
-          background_embeded(*current_item);
+          background_embedded(*current_item);
         }
-        foreground_embeded(m_search_notes_widget);
+        foreground_embedded(m_search_notes_widget);
       }
       break;
     default:
@@ -212,11 +226,11 @@ namespace gnote {
     // Select "All Notes" in the notebooks list
     m_search_notes_widget.select_all_notes_notebook();
 
-    if(m_embed_box.get_children().size() == 0 && m_embeded_widgets.size() > 0) {
-      foreground_embeded(**m_embeded_widgets.rbegin());
+    if(m_embed_box.get_children().size() == 0 && m_embedded_widgets.size() > 0) {
+      foreground_embedded(**m_embedded_widgets.rbegin());
     }
-    std::vector<Gtk::Widget*> embeded = m_embed_box.get_children();
-    if(embeded.size() == 1 && embeded.front() == &m_search_notes_widget) {
+    std::vector<Gtk::Widget*> embedded = m_embed_box.get_children();
+    if(embedded.size() == 1 && embedded.front() == &m_search_notes_widget) {
       m_search_notes_widget.focus_search_entry();
     }
     NoteRecentChangesParent::on_show();
@@ -224,39 +238,39 @@ namespace gnote {
 
   void NoteRecentChanges::set_search_text(const std::string & value)
   {
-    //TODO: handle non-search embeded widgets
+    //TODO: handle non-search embedded widgets
     m_search_notes_widget.set_search_text(value);
   }
 
-  void NoteRecentChanges::embed_widget(utils::EmbedableWidget & widget)
+  void NoteRecentChanges::embed_widget(utils::EmbeddableWidget & widget)
   {
-    if(std::find(m_embeded_widgets.begin(), m_embeded_widgets.end(), &widget) == m_embeded_widgets.end()) {
+    if(std::find(m_embedded_widgets.begin(), m_embedded_widgets.end(), &widget) == m_embedded_widgets.end()) {
       widget.embed(this);
-      m_embeded_widgets.push_back(&widget);
+      m_embedded_widgets.push_back(&widget);
     }
-    utils::EmbedableWidget *current = currently_embeded();
+    utils::EmbeddableWidget *current = currently_embedded();
     if(current && current != &widget) {
-      background_embeded(*current);
+      background_embedded(*current);
     }
-    foreground_embeded(widget);
+    foreground_embedded(widget);
   }
 
-  void NoteRecentChanges::unembed_widget(utils::EmbedableWidget & widget)
+  void NoteRecentChanges::unembed_widget(utils::EmbeddableWidget & widget)
   {
     bool show_other = false;
-    std::list<utils::EmbedableWidget*>::iterator iter = std::find(
-      m_embeded_widgets.begin(), m_embeded_widgets.end(), &widget);
-    if(iter != m_embeded_widgets.end()) {
+    std::list<utils::EmbeddableWidget*>::iterator iter = std::find(
+      m_embedded_widgets.begin(), m_embedded_widgets.end(), &widget);
+    if(iter != m_embedded_widgets.end()) {
       if(is_foreground(**iter)) {
-        background_embeded(widget);
+        background_embedded(widget);
         show_other = true;
       }
-      m_embeded_widgets.erase(iter);
+      m_embedded_widgets.erase(iter);
       widget.unembed();
     }
     if(show_other) {
-      if(m_embeded_widgets.size()) {
-	foreground_embeded(**m_embeded_widgets.rbegin());
+      if(m_embedded_widgets.size()) {
+	foreground_embedded(**m_embedded_widgets.rbegin());
       }
       else if(get_visible()) {
         on_close_window();
@@ -264,27 +278,33 @@ namespace gnote {
     }
   }
 
-  void NoteRecentChanges::foreground_embeded(utils::EmbedableWidget & widget)
+  void NoteRecentChanges::foreground_embedded(utils::EmbeddableWidget & widget)
   {
     try {
-      if(currently_embeded() == &widget) {
+      if(currently_embedded() == &widget) {
         return;
       }
       Gtk::Widget &wid = dynamic_cast<Gtk::Widget&>(widget);
       m_embed_box.pack_start(wid, true, true, 0);
       widget.foreground();
       wid.show();
+      m_all_notes_button->set_sensitive(
+        dynamic_cast<SearchNotesWidget*>(&widget) != &m_search_notes_widget);
+      on_embedded_name_changed(widget.get_name());
+      m_current_embedded_name_slot = widget.signal_name_changed
+        .connect(sigc::mem_fun(*this, &NoteRecentChanges::on_embedded_name_changed));
     }
     catch(std::bad_cast&) {
     }
   }
 
-  void NoteRecentChanges::background_embeded(utils::EmbedableWidget & widget)
+  void NoteRecentChanges::background_embedded(utils::EmbeddableWidget & widget)
   {
     try {
-      if(currently_embeded() != &widget) {
+      if(currently_embedded() != &widget) {
         return;
       }
+      m_current_embedded_name_slot.disconnect();
       Gtk::Widget &wid = dynamic_cast<Gtk::Widget&>(widget);
       widget.background();
       m_embed_box.remove(wid);
@@ -293,12 +313,12 @@ namespace gnote {
     }
   }
 
-  bool NoteRecentChanges::is_foreground(utils::EmbedableWidget & widget)
+  bool NoteRecentChanges::is_foreground(utils::EmbeddableWidget & widget)
   {
     std::vector<Gtk::Widget*> current = m_embed_box.get_children();
     for(std::vector<Gtk::Widget*>::iterator iter = current.begin();
         iter != current.end(); ++iter) {
-      if(dynamic_cast<utils::EmbedableWidget*>(*iter) == &widget) {
+      if(dynamic_cast<utils::EmbeddableWidget*>(*iter) == &widget) {
         return true;
       }
     }
@@ -306,52 +326,10 @@ namespace gnote {
     return false;
   }
 
-  void NoteRecentChanges::on_embeded_widget_menu_item_toggled(Gtk::RadioMenuItem *item,
-                                                              utils::EmbedableWidget * widget)
-  {
-    if(std::find(m_embeded_widgets.begin(), m_embeded_widgets.end(), widget)
-       == m_embeded_widgets.end()) {
-      return;
-    }
-    if(item->get_active()) {
-      foreground_embeded(*widget);
-    }
-    else {
-      background_embeded(*widget);
-    }
-  }
-
-  void NoteRecentChanges::on_menu_show()
-  {
-    std::vector<Gtk::Widget*> items = m_menu->get_children();
-    for(std::vector<Gtk::Widget*>::iterator iter = items.begin(); iter != items.end(); ++iter) {
-      m_menu->remove(**iter);
-    }
-
-    utils::EmbedableWidget *current = currently_embeded();
-    Gtk::RadioMenuItem *active_item = NULL;
-    for(std::list<utils::EmbedableWidget*>::iterator iter = m_embeded_widgets.begin();
-        iter != m_embeded_widgets.end(); ++iter) {
-      Gtk::RadioMenuItem *item = manage(new Gtk::RadioMenuItem(m_tool_menu_group, (*iter)->get_name()));
-      item->signal_toggled().connect(
-        boost::bind(sigc::mem_fun(*this, &NoteRecentChanges::on_embeded_widget_menu_item_toggled),
-                    item, *iter));
-      item->show();
-      m_menu->append(*item);
-      if(*iter == current) {
-        active_item = item;
-      }
-    }
-
-    if(active_item) {
-      active_item->set_active(true);
-    }
-  }
-
-  utils::EmbedableWidget *NoteRecentChanges::currently_embeded()
+  utils::EmbeddableWidget *NoteRecentChanges::currently_embedded()
   {
     std::vector<Gtk::Widget*> children = m_embed_box.get_children();
-    return children.size() ? dynamic_cast<utils::EmbedableWidget*>(children[0]) : NULL;
+    return children.size() ? dynamic_cast<utils::EmbeddableWidget*>(children[0]) : NULL;
   }
 
   bool NoteRecentChanges::on_map_event(GdkEventAny *evt)
@@ -361,5 +339,15 @@ namespace gnote {
     return res;
   }
 
+  void NoteRecentChanges::on_embedded_name_changed(const std::string & name)
+  {
+    std::string title;
+    if(name != "") {
+      title = "[" + name + "] - ";
+    }
+    title += _("Notes");
+    set_title(title);
+  }
+
 }
 
