@@ -29,6 +29,7 @@
 #include <gtkmm/table.h>
 
 #include "debug.hpp"
+#include "iconmanager.hpp"
 #include "notemanager.hpp"
 #include "notewindow.hpp"
 #include "recenttreeview.hpp"
@@ -42,22 +43,11 @@
 namespace gnote {
 
 std::list<std::string> SearchNotesWidget::s_previous_searches;
-bool SearchNotesWidget::s_static_inited = false;
-Glib::RefPtr<Gdk::Pixbuf> SearchNotesWidget::s_note_icon;
-Glib::RefPtr<Gdk::Pixbuf> SearchNotesWidget::s_all_notes_icon;
-Glib::RefPtr<Gdk::Pixbuf> SearchNotesWidget::s_unfiled_notes_icon;
-Glib::RefPtr<Gdk::Pixbuf> SearchNotesWidget::s_notebook_icon;
 
-void SearchNotesWidget::_init_static()
+
+Glib::RefPtr<Gdk::Pixbuf> SearchNotesWidget::get_note_icon()
 {
-  if(s_static_inited) {
-    return;
-  }
-  s_note_icon = utils::get_icon ("note", 22);
-  s_all_notes_icon = utils::get_icon ("filter-note-all", 22);
-  s_unfiled_notes_icon = utils::get_icon ("filter-note-unfiled", 22);
-  s_notebook_icon = utils::get_icon ("notebook", 22);
-  s_static_inited = true;
+  return IconManager::obj().get_icon(IconManager::NOTE, 22);
 }
 
 
@@ -75,7 +65,6 @@ SearchNotesWidget::SearchNotesWidget(NoteManager & m)
   , m_notebook_list_context_menu(NULL)
   , m_initial_position_restored(false)
 {
-  _init_static();
   make_actions();
 
   Gtk::Label *label = manage(new Gtk::Label (_("_Search:"), true));
@@ -156,6 +145,8 @@ SearchNotesWidget::SearchNotesWidget(NoteManager & m)
     .connect(sigc::mem_fun(*this, &SearchNotesWidget::on_note_added_to_notebook));
   notebooks::NotebookManager::instance().signal_note_removed_from_notebook()
     .connect(sigc::mem_fun(*this, &SearchNotesWidget::on_note_removed_from_notebook));
+  notebooks::NotebookManager::instance().signal_note_pin_status_changed
+    .connect(sigc::mem_fun(*this, &SearchNotesWidget::on_note_pin_status_changed));
 
   // Set the focus chain for the top-most containers
   std::vector<Gtk::Widget*> focus_chain;
@@ -196,7 +187,12 @@ SearchNotesWidget::~SearchNotesWidget()
 
 std::string SearchNotesWidget::get_name() const
 {
-  return "All Notes"; //TODO change accrding selected notebook
+  notebooks::Notebook::Ptr selected_notebook = get_selected_notebook();
+  if(!selected_notebook
+     || std::tr1::dynamic_pointer_cast<notebooks::AllNotesNotebook>(selected_notebook)) {
+    return "";
+  }
+  return selected_notebook->get_name();
 }
 
 void SearchNotesWidget::make_actions()
@@ -448,7 +444,7 @@ void SearchNotesWidget::save_position()
   int width;
   int height;
 
-  utils::EmbedableWidgetHost *current_host = host();
+  utils::EmbeddableWidgetHost *current_host = host();
   if(!current_host || !current_host->running()) {
     return;
   }
@@ -481,15 +477,7 @@ void SearchNotesWidget::notebook_pixbuf_cell_data_func(Gtk::CellRenderer * rende
   }
 
   Gtk::CellRendererPixbuf *crp = dynamic_cast<Gtk::CellRendererPixbuf*>(renderer);
-  if(std::tr1::dynamic_pointer_cast<notebooks::AllNotesNotebook>(notebook)) {
-    crp->property_pixbuf() = s_all_notes_icon;
-  }
-  else if(std::tr1::dynamic_pointer_cast<notebooks::UnfiledNotesNotebook>(notebook)) {
-    crp->property_pixbuf() = s_unfiled_notes_icon;
-  }
-  else {
-    crp->property_pixbuf() = s_notebook_icon;
-  }
+  crp->property_pixbuf() = notebook->get_icon();
 }
 
 void SearchNotesWidget::notebook_text_cell_data_func(Gtk::CellRenderer * renderer,
@@ -591,6 +579,7 @@ void SearchNotesWidget::on_notebook_selection_changed()
   }
 
   update_results();
+  signal_name_changed(get_name());
 }
 
 bool SearchNotesWidget::on_notebooks_tree_button_pressed(GdkEventButton *ev)
@@ -630,7 +619,7 @@ bool SearchNotesWidget::on_notebooks_key_pressed(GdkEventKey *ev)
   return false; // Let Escape be handled by the window.
 }
 
-notebooks::Notebook::Ptr SearchNotesWidget::get_selected_notebook()
+notebooks::Notebook::Ptr SearchNotesWidget::get_selected_notebook() const
 {
   Gtk::TreeIter iter;
 
@@ -690,7 +679,7 @@ void SearchNotesWidget::update_results()
     std::string nice_date = utils::get_pretty_print_date(note->change_date(), true);
 
     Gtk::TreeIter iter = m_store->append();
-    iter->set_value(0, s_note_icon);  /* icon */
+    iter->set_value(0, get_note_icon());  /* icon */
     iter->set_value(1, note->get_title()); /* title */
     iter->set_value(2, nice_date);  /* change date */
     iter->set_value(3, note);      /* note */
@@ -761,13 +750,8 @@ bool SearchNotesWidget::filter_notes(const Gtk::TreeIter & iter)
   }
 
   notebooks::Notebook::Ptr selected_notebook = get_selected_notebook();
-  if(std::tr1::dynamic_pointer_cast<notebooks::UnfiledNotesNotebook>(selected_notebook)) {
-    // If the note belongs to a notebook, return false
-    // since the only notes that should be shown in this
-    // case are notes that are unfiled (not in a notebook).
-    if(notebooks::NotebookManager::instance().get_notebook_from_note(note)) {
-      return false;
-    }
+  if(!selected_notebook || !selected_notebook->contains_note(note)) {
+    return false;
   }
 
   bool passes_search_filter = filter_by_search(note);
@@ -1377,7 +1361,7 @@ void SearchNotesWidget::add_note(const Note::Ptr & note)
   std::string nice_date =
     utils::get_pretty_print_date(note->change_date(), true);
   Gtk::TreeIter iter = m_store->append();
-  iter->set_value(m_column_types.icon, s_note_icon);
+  iter->set_value(m_column_types.icon, get_note_icon());
   iter->set_value(m_column_types.title, note->get_title());
   iter->set_value(m_column_types.change_date, nice_date);
   iter->set_value(m_column_types.note, note);
@@ -1464,6 +1448,12 @@ void SearchNotesWidget::on_note_removed_from_notebook(const Note &,
   update_results();
 }
 
+void SearchNotesWidget::on_note_pin_status_changed(const Note &, bool)
+{
+  restore_matches_window();
+  update_results();
+}
+
 Gtk::Menu *SearchNotesWidget::get_note_list_context_menu()
 {
   if(!m_note_list_context_menu) {
@@ -1561,7 +1551,7 @@ void SearchNotesWidget::on_delete_notebook()
 
 void SearchNotesWidget::foreground()
 {
-  utils::EmbedableWidget::foreground();
+  utils::EmbeddableWidget::foreground();
   restore_position();
   Gtk::Window *win = dynamic_cast<Gtk::Window*>(host());
   if(win) {
@@ -1571,7 +1561,7 @@ void SearchNotesWidget::foreground()
 
 void SearchNotesWidget::background()
 {
-  utils::EmbedableWidget::background();
+  utils::EmbeddableWidget::background();
   save_position();
   Gtk::Window *win = dynamic_cast<Gtk::Window*>(host());
   if(win) {
